Module path_utils

Macros

abs_file
Wrapper for AbsPathBuf::new_workspace_rel(file!()), for use as a drop-in replacement for file!().
dir
The workspace relative directory for this file, internally using the file!() macro.

Structs

AbsPathBuf
A newtype PathBuf with several indications:
FsExt
Better Fs, actually outputs missing path
GlobFilter
glob for watch patterns
PathExt
ReadDir
Read a directory or file into a Vec. All options are false by default. All paths will include the root.
ReadFile
A nicer read file that actually outputs the missing path
WsPathBuf
Workspace PathBuf

Enums

FsError
An fs error that actuall outputs the missing path

Type Aliases

FsResult