pub struct ReadDir {
pub files: bool,
pub dirs: bool,
pub recursive: bool,
pub root: bool,
}Expand description
Read a directory or file into a Vec
Fields
files: boolinclude files
dirs: boolinclude directories
recursive: boolsearch subdirectories
root: boolinclude the root directory
Implementations
Sourceimpl ReadDir
impl ReadDir
Sourcepub fn all(root: impl AsRef<Path>) -> FsResult<Vec<PathBuf>>
pub fn all(root: impl AsRef<Path>) -> FsResult<Vec<PathBuf>>
Get all files and directories in a directory, not recursive
Sourcepub async fn all_async(root: impl AsRef<Path>) -> FsResult<Vec<PathBuf>>
pub async fn all_async(root: impl AsRef<Path>) -> FsResult<Vec<PathBuf>>
Async: Get all files and directories in a directory, not recursive
Sourcepub fn dirs(root: impl AsRef<Path>) -> FsResult<Vec<PathBuf>>
pub fn dirs(root: impl AsRef<Path>) -> FsResult<Vec<PathBuf>>
Get all dirs in a directory, not recursive
Sourcepub async fn dirs_async(root: impl AsRef<Path>) -> FsResult<Vec<PathBuf>>
pub async fn dirs_async(root: impl AsRef<Path>) -> FsResult<Vec<PathBuf>>
Async: Get all dirs in a directory, not recursive
Sourcepub fn files(root: impl AsRef<Path>) -> FsResult<Vec<PathBuf>>
pub fn files(root: impl AsRef<Path>) -> FsResult<Vec<PathBuf>>
Get all files in a directory, not recursive
Sourcepub async fn files_async(root: impl AsRef<Path>) -> FsResult<Vec<PathBuf>>
pub async fn files_async(root: impl AsRef<Path>) -> FsResult<Vec<PathBuf>>
Async: Get all files in a directory, not recursive
Sourcepub fn all_recursive(root: impl AsRef<Path>) -> FsResult<Vec<PathBuf>>
pub fn all_recursive(root: impl AsRef<Path>) -> FsResult<Vec<PathBuf>>
Get all files and directories recursively
Sourcepub async fn all_recursive_async(
root: impl AsRef<Path>,
) -> FsResult<Vec<PathBuf>>
pub async fn all_recursive_async( root: impl AsRef<Path>, ) -> FsResult<Vec<PathBuf>>
Async: Get all files and directories recursively
Sourcepub fn dirs_recursive(root: impl AsRef<Path>) -> FsResult<Vec<PathBuf>>
pub fn dirs_recursive(root: impl AsRef<Path>) -> FsResult<Vec<PathBuf>>
Get all subdirectories recursively
Sourcepub async fn dirs_recursive_async(
root: impl AsRef<Path>,
) -> FsResult<Vec<PathBuf>>
pub async fn dirs_recursive_async( root: impl AsRef<Path>, ) -> FsResult<Vec<PathBuf>>
Async: Get all subdirectories recursively
Sourcepub fn files_recursive(root: impl AsRef<Path>) -> FsResult<Vec<PathBuf>>
pub fn files_recursive(root: impl AsRef<Path>) -> FsResult<Vec<PathBuf>>
Get all files recursively
Sourcepub async fn files_recursive_async(
root: impl AsRef<Path>,
) -> FsResult<Vec<PathBuf>>
pub async fn files_recursive_async( root: impl AsRef<Path>, ) -> FsResult<Vec<PathBuf>>
Async: Get all files recursively
Sourcepub fn read(&self, root: impl AsRef<Path>) -> FsResult<Vec<PathBuf>>
pub fn read(&self, root: impl AsRef<Path>) -> FsResult<Vec<PathBuf>>
Read dir with the provided options. if the root is a file, the file will be returned.
Sourcepub async fn read_async(&self, root: impl AsRef<Path>) -> FsResult<Vec<PathBuf>>
pub async fn read_async(&self, root: impl AsRef<Path>) -> FsResult<Vec<PathBuf>>
Async version: Read dir with the provided options. if the root is a file, the file will be returned.
Sourcepub fn read_dirs_ok(
&self,
paths: impl IntoIterator<Item = impl AsRef<Path>>,
) -> FsResult<Vec<PathBuf>>
pub fn read_dirs_ok( &self, paths: impl IntoIterator<Item = impl AsRef<Path>>, ) -> FsResult<Vec<PathBuf>>
Read dir recursive for each path, ignoring DirNotFound errors