Module utils

Re-exports

pub use log::*;
pub use sleep::*;

Modules

log
macros
sleep

Structs

BuildUtils
Running build.rs files has several nuances, this struct is a helper that exposes some of these.
Tree
Very simple general purpose tree structure.

Traits

Pipeline
Basically a FnOnce trait, but not nightly and a little less awkward to implement.
PipelineTarget
Utilities for method-chaining on any type. Very similar in its goals to tap
PipelineTargetIter
Utilities for method-chaining on any type. Very similar in its goals to tap
PipelineTargetString
PipelineTargetVec