Re-exports
Modules
Structs
- Build
Utils - Running
build.rsfiles has several nuances, this struct is a helper that exposes some of these. - Tree
- Very simple general purpose tree structure.
Traits
- Pipeline
- Basically a
FnOncetrait, but not nightly and a little less awkward to implement. - Pipeline
Target - Utilities for method-chaining on any type.
Very similar in its goals to
tap - Pipeline
Target Iter - Utilities for method-chaining on any type.
Very similar in its goals to
tap - Pipeline
Target String - Pipeline
Target Vec